| cds_accept_licence | R Documentation |
Call this function if you wish to accept a specific license.
cds_accept_licence(license, revision, ..., token = cds_get_token())
license |
The license id you wish to accept. |
revision |
The revision number of the license you are accepting. Should always be the latest revision. |
... |
Ignored |
token |
An API key to be used for authentication. Will use
|
Returns a data.frame containing the accepted license
Other licences:
cds_accepted_licences(),
cds_list_licences()
if (interactive() && cds_token_works()) {
cds_accept_licence("cc-by", 1)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.