cds_accepted_licences: List accepted licences

View source: R/licenses.R

cds_accepted_licencesR Documentation

List accepted licences

Description

In order to use specific features of the Climate Data Service, you may first need to accept specific licences. This function will list all licenses you have accepted.

Usage

cds_accepted_licences(
  scope = c("all", "dataset", "portal"),
  ...,
  token = cds_get_token()
)

Arguments

scope

Scope of the licenses to be listed should be one of "all" (default), "dataset" or "portal".

...

Ignored

token

An API key to be used for authentication. Will use cds_get_token() by default.

Value

Returns a data.frame listing the accepted licenses.

See Also

Other licences: cds_accept_licence(), cds_list_licences()

Examples

if (interactive() && cds_token_works()) {
  cds_accepted_licences("portal")
}

CopernicusClimate documentation built on Jan. 8, 2026, 1:08 a.m.