This function provides an overview of parameters that can be used to subset a
dataset. It can help you set up a request with cds_submit_job() or cds_build_request().
Value
A data.frame with aspects of the dataset that can be subsetted, when defining
a job. See also cds_submit_job() and cds_build_request()
See also
Other helper-functions:
cds_build_request(),
cds_cite_dataset(),
cds_estimate_costs(),
cds_python_to_r()
Examples
if (interactive() && cds_token_works()) {
cds_dataset_form("reanalysis-era5-pressure-levels")
}