cds_list_licences: Obtain a list of licences that can be accepted

View source: R/licenses.R

cds_list_licencesR Documentation

Obtain a list of licences that can be accepted

Description

Some datasets require you to accept specific licences. This function will provide an overview of all licences associated with datasets and can be accepted.

Usage

cds_list_licences(...)

Arguments

...

Ignored

Value

Returns a data.frame of available licences that can be accepted.

See Also

Other licences: cds_accept_licence(), cds_accepted_licences()

Examples

if (interactive()) {
  cds_list_licences()
}

CopernicusClimate documentation built on Jan. 8, 2026, 1:08 a.m.