| cds_list_datasets | R Documentation |
This will help you decide which datasets you wish to obtain.
cds_list_datasets(dataset, ...)
cds_search_datasets(search, keywords, page = 0, limit = 50, ...)
dataset |
A specific dataset for which to list details. If missing all datasets are listed. |
... |
Ignored |
search |
A string containing free text search terms to look for in the available datasets. |
keywords |
A (vector of) string containing specific keywords. Should be listed in
|
page |
When there are more search results than |
limit |
Use to limit the number of search results. Defaults to |
A data.frame listing the datasets from the Climate Data Service. In
case of cds_search_datasets(), attributes named SearchMeta are added containing
the number of matching and number of returned datasets.
if (interactive()) {
cds_list_datasets()
cds_search_datasets("rain", "Temporal coverage: Future")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.