| cds_starred | R Documentation |
Use stars to keep track of your favourite datasets. Use these functions to add or remove a star.
cds_starred(..., token = cds_get_token())
cds_assign_star(dataset, ..., token = cds_get_token())
cds_remove_star(dataset, ..., token = cds_get_token())
... |
Ignored |
token |
An API key to be used for authentication. Will use
|
dataset |
Name of the dataset to assign a star to, or remove it from. |
In case of cds_assign_star() returns the name of the starred
dataset. In case of cds_starred() a vector of names of starred datasets.
In case of cds_remove_star() returns NULL invisibly.
if (interactive() && cds_token_works()) {
cds_assign_star("reanalysis-carra-single-levels")
cds_starred()
cds_remove_star("reanalysis-carra-single-levels")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.