| cds_submit_job | R Documentation |
Submit a request to the Copernicus Climate Data Service to download
(part of) a dataset. If the request is successful, a job identifier is
returned which can be used to actually download the data (cds_download_jobs()).
cds_submit_job(
dataset,
...,
wait = TRUE,
check_quota = TRUE,
check_licence = TRUE,
token = cds_get_token()
)
dataset |
The dataset name to be downloaded, or a |
... |
Subsetting parameters passed onto |
wait |
A |
check_quota |
Each account has a quota of data that can be downloaded.
If this argument is set to |
check_licence |
Datasets generally require you to accept certain terms of use.
If this argument is set to |
token |
An API key to be used for authentication. Will use
|
Returns a data.frame containing information about the submitted job.
if (interactive() && cds_token_works()) {
job <- cds_submit_job(
dataset = "reanalysis-era5-pressure-levels",
variable = "geopotential",
product_type = "reanalysis",
area = c(n = 55, w = -1, s = 50, e = 10),
year = "2024",
month = "03",
day = "01",
pressure_level = "1000",
data_format = "netcdf"
)
## Or split into two separate steps:
req <- cds_build_request(
dataset = "reanalysis-era5-pressure-levels",
variable = "geopotential",
product_type = "reanalysis",
area = c(n = 55, w = -1, s = 50, e = 10),
year = "2024",
month = "03",
day = "01",
pressure_level = "1000",
data_format = "netcdf"
)
job <- cds_submit_job(req)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.