| cds_accepted_licences | R Documentation |
In order to use specific features of the Climate Data Service, you may first need to accept specific licences. This function will list all licenses you have accepted.
cds_accepted_licences(
scope = c("all", "dataset", "portal"),
...,
token = cds_get_token()
)
scope |
Scope of the licenses to be listed should be one of |
... |
Ignored |
token |
An API key to be used for authentication. Will use
|
Returns a data.frame listing the accepted licenses.
Other licences:
cds_accept_licence(),
cds_list_licences()
if (interactive() && cds_token_works()) {
cds_accepted_licences("portal")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.