| cds_check_authentication | R Documentation |
Checks if the specified API key can be used for authentication at the Climate Data Service.
cds_check_authentication(token = cds_get_token(), ...)
cds_token_works(token = cds_get_token(), ...)
token |
An API key to be used for authentication. Will use
|
... |
Ignored |
cds_check_authentication() will return
some account information when successful but throws an error if
it is not. In contrast cds_token_works() returns a logical
value and will not throw an error upon failure.
if (interactive() && cds_token_works()) {
cds_check_authentication()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.