cds_dataset_form: Obtain an overview of options to subset a dataset

View source: R/catalogue.R

cds_dataset_formR Documentation

Obtain an overview of options to subset a dataset

Description

This function provides an overview of parameters that can be used to subset a dataset. It can help you set up a request with cds_submit_job() or cds_build_request().

Usage

cds_dataset_form(dataset, ...)

Arguments

dataset

A name of a dataset to explore

...

Ignored

Value

A data.frame with aspects of the dataset that can be subsetted, when defining a job. See also cds_submit_job() and cds_build_request()

Examples

if (interactive() && cds_token_works()) {
  cds_dataset_form("reanalysis-era5-pressure-levels")
}

CopernicusClimate documentation built on Jan. 8, 2026, 1:08 a.m.