| cds_dataset_form | R Documentation |
This function provides an overview of parameters that can be used to subset a
dataset. It can help you set up a request with cds_submit_job() or cds_build_request().
cds_dataset_form(dataset, ...)
dataset |
A name of a dataset to explore |
... |
Ignored |
A data.frame with aspects of the dataset that can be subsetted, when defining
a job. See also cds_submit_job() and cds_build_request()
if (interactive() && cds_token_works()) {
cds_dataset_form("reanalysis-era5-pressure-levels")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.