| cds_list_jobs | R Documentation |
Once submitted with cds_submit_job() you can check the status of the job with
this function. You can list all available jobs, or specific jobs.
cds_list_jobs(
job_id = NULL,
status = NULL,
limit = 50,
...,
token = cds_get_token()
)
job_id |
The id of a specific job, if you want the results for that job. If |
status |
Only return jobs with the status stated by this argument. Default is |
limit |
Use to limit the number of listed results. Defaults to |
... |
Ignored |
token |
An API key to be used for authentication. Will use
|
Returns a data.frame of submitted jobs.
if (interactive() && cds_token_works()) {
cds_list_jobs()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.