Learn R Programming

CopernicusClimate (version 0.0.4)

cds_list_jobs: List jobs submitted to the Climate Data Service

Description

Once submitted with cds_submit_job() you can check the status of the job with this function. You can list all available jobs, or specific jobs.

Usage

cds_list_jobs(
  job_id = NULL,
  status = NULL,
  limit = 50,
  ...,
  token = cds_get_token()
)

Value

Returns a data.frame of submitted jobs.

Arguments

job_id

The id of a specific job, if you want the results for that job. If NULL (default) it is ignored.

status

Only return jobs with the status stated by this argument. Default is NULL meaning that jobs with any status are returned. Should be any of "accepted", "running", "successful", "failed", or "rejected".

limit

Use to limit the number of listed results. Defaults to 50.

...

Ignored

token

An API key to be used for authentication. Will use cds_get_token() by default.

Examples

Run this code
if (interactive() && cds_token_works()) {
  cds_list_jobs()
}

Run the code above in your browser using DataLab